@@ -5,20 +5,22 @@
 # Written by Andreas Jung for Haufe Mediengruppe, Freiburg, Germany
 # and ZOPYX Ltd. & Co. KG, Tuebingen, Germany
 ##########################################################################
-
-
 """
 Utility methods for SqlAlchemy
 """
 
 import threading
 
-from sqlalchemy import Table 
-from sqlalchemy.orm import mapper, relation, class_mapper
+from sqlalchemy import Table
 from sqlalchemy.ext.declarative import DeclarativeMeta
+from sqlalchemy.orm import class_mapper
+from sqlalchemy.orm import mapper
+from sqlalchemy.orm import relation
+
 
 marker = object
 
+
 class Proxy(dict):
     """ Dict-Proxy for mapped objects providing
         attribute-style access.
@@ -35,12 +37,12 @@ class Proxy(dict):
         if name in dict.keys(self):
             return self.get(name)
 
-        return super(dict, self).__getattribute__(name) 
+        return super(dict, self).__getattribute__(name)
 
     def __getattr__(self, name, default=None):
         if name in dict.keys(self):
             return self.get(name, default)
-        return super(dict, self).__getattr__(name, default) 
+        return super(dict, self).__getattr__(name, default)
 
 
 class MappedClassBase(object):
@@ -49,7 +51,6 @@ class MappedClassBase(object):
     # Zope 2 security magic.......buuuuuuuhhhhhh
     __allow_access_to_unprotected_subobjects__ = 1
 
-
     def __init__(self, **kw):
         """ accepts keywords arguments used for initialization of
             mapped attributes/columns.
@@ -59,7 +60,6 @@ class MappedClassBase(object):
         for k, v in kw.items():
             setattr(self, k, v)
 
-
     def clone(self):
         """ Create a  pristine copy.
             Use this method if you need to reinsert a copy of the current
@@ -71,12 +71,10 @@ class MappedClassBase(object):
             d[col] = getattr(self, col)
         return self.__class__(**d)
 
-
     def asDict(self):
         """ Returns current object as a dict"""
         return Proxy(self)
 
-
     def getMapper(self, name):
         """ Return a mapper associated with the current mapper.
             If this mapper represents a table A having a relationship
@@ -84,16 +82,15 @@ class MappedClassBase(object):
             self.getMapper('B'). This method is useful if you don't want
             to pass the wrapper around this the wrapper is officially
             the only way to get hold of a mapper by name. See also
-            http://groups.google.com/group/sqlalchemy/browse_thread/thread/18fb2e2818bdc032/5c2dfd71679925cb#5c2dfd71679925cb
+            http://groups.google.com/group/sqlalchemy/browse_thread/thread/18fb2e2818bdc032/5c2dfd71679925cb#5c2dfd71679925cb  # NOQA: E501
         """
         try:
-            return class_mapper(self.__class__).get_property(name).mapper.class_
+            return class_mapper(
+                self.__class__).get_property(name).mapper.class_
         except AttributeError:
             return class_mapper(self.__class__).props[name].mapper.class_
 
 
-
-
 class MapperFactory(object):
     """ a factory for table and mapper objects """
 
@@ -106,22 +103,20 @@ class MapperFactory(object):
 
             'properties' - dict containing additional informations about
 
-            'cls' - (optional) class used as base for creating the mapper 
+            'cls' - (optional) class used as base for creating the mapper
             class (will be autogenerated if not available).
-        """ 
+        """
 
         if cls is None:
-            newCls = type('_mapped_%s' % str(table.name), (MappedClassBase,), {})
+            newCls = type('_mapped_%s' % str(table.name),
+                          (MappedClassBase,), {})
         else:
             newCls = cls
 
-        mapper(newCls, 
-               table, 
-               properties=properties) 
+        mapper(newCls, table, properties=properties)
         return newCls
 
 
-
 class LazyMapperCollection(dict):
     """ Implements a cache for table mappers """
 
@@ -156,7 +151,8 @@ class LazyMapperCollection(dict):
             # if not: introspect table definition
             if table is None:
 
-                table_name = self._model.get(name, {}).get('table_name') or name
+                tname = self._model.get(name, {}).get('table_name')
+                table_name = tname or name
 
                 # check for 'schema.tablename'
                 if '.' in table_name:
@@ -164,8 +160,8 @@ class LazyMapperCollection(dict):
                 else:
                     tablename, schema = table_name, None
 
-                table = Table(tablename, 
-                              self._metadata, 
+                table = Table(tablename,
+                              self._metadata,
                               schema=schema,
                               autoload=True)
 
@@ -174,29 +170,35 @@ class LazyMapperCollection(dict):
             if name in self._model:
                 mapper_class = self._model[name].get('mapper_class')
 
-
             # use auto-introspected table dependencies for creating
             # the 'properties' dict that tells the mapper about
-            # relationships to other tables 
+            # relationships to other tables
 
             dependent_table_names = []
             if name in self._model:
 
-                if self._model[name].get('relations') != None:
-                    dependent_table_names = self._model[name].get('relations', []) or []
-                elif self._model[name].get('autodetect_relations', False) == True:
+                adr = self._model[name].get('autodetect_relations', False)
+
+                if self._model[name].get('relations') is not None:
+                    dependent_table_names = self._model[name].get('relations',
+                                                                  []) or []
+                elif adr is True:
 
                     if self._dependent_tables is None:
                         # Introspect table dependencies once. The introspection
-                        # is deferred until the moment where we really need to 
+                        # is deferred until the moment where we really need to
                         # introspect them
-                        if hasattr(self._wrapper, 'findDependentTables'):
-                            self._dependent_tables = self._wrapper.findDependentTables(ignoreErrors=True)
+                        meth = getattr(self._wrapper,
+                                       'findDependentTables',
+                                       None)
+                        if meth is not None:
+                            self._dependent_tables = meth(ignoreErrors=True)
                         else:
                             self._dependent_tables = {}
 
-                    dependent_table_names = self._dependent_tables.get(name, []) or []
-                
+                    dependent_table_names = (
+                        self._dependent_tables.get(name, []) or [])
+
             # build additional property dict for mapper
             properties = {}
 
@@ -206,24 +208,25 @@ class LazyMapperCollection(dict):
                 table_ref_mapper = self.getMapper(table_refname)
 
                 # add the mapper as relation to the properties dict
-                properties[table_refname] = relation(table_ref_mapper, cascade=self._model.get(name, {}).get('cascade'))
+                properties[table_refname] = (
+                    relation(table_ref_mapper,
+                             cascade=self._model.get(name, {}).get('cascade')))
 
-            # create a mapper and cache it 
+            # create a mapper and cache it
             if mapper_class and 'c' in mapper_class.__dict__:
                 mapper = mapper_class
             else:
-                mapper =  self._mapper_factory(table, 
-                                               properties=properties,
-                                               cls=mapper_class)
+                mapper = self._mapper_factory(table,
+                                              properties=properties,
+                                              cls=mapper_class)
 
             self._registerMapper(mapper, name)
 
         return self[name]
 
-
     def _registerMapper(self, mapper, name):
         """ register a mapper under a given name """
-    
+
         self._lock.acquire()
         self[name] = mapper
         self._lock.release()
